@@ -27,8 +27,7 @@
 
 /**
  * SECTION:clutter-alpha
- * @short_description: A class for calculating an alpha value as a function
- * of time.
+ * @short_description: A class for calculating a value as a function of time
  *
  * #ClutterAlpha is a class for calculating an floating point value
  * dependent only on the position of a #ClutterTimeline.
@@ -77,17 +76,17 @@
  *     function called my_sine_alpha(). The defined #ClutterAlpha
  *     instance can be reused in multiple #ClutterBehaviour
  *     definitions or for #ClutterAnimation definitions.</para>
- *     <programlisting>
- *  {
- *    "id" : "sine-alpha",
- *    "timeline" : {
- *      "id" : "sine-timeline",
- *      "duration" : 500,
- *      "loop" : true
- *    },
- *    "function" : "my_sine_alpha"
- *  }
- *     </programlisting>
+ *     <programlisting><![CDATA[
+ * {
+ *   "id" : "sine-alpha",
+ *   "timeline" : {
+ *     "id" : "sine-timeline",
+ *     "duration" : 500,
+ *     "loop" : true
+ *   },
+ *   "function" : "my_sine_alpha"
+ * }
+ *    ]]></programlisting>
  *   </example>
  *   <para>For the way to define the #ClutterAlpha:mode property
  *   inside a ClutterScript fragment, see <link
@@ -141,9 +140,13 @@ enum
   
   PROP_TIMELINE,
   PROP_ALPHA,
-  PROP_MODE
+  PROP_MODE,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 static void
 timeline_new_frame_cb (ClutterTimeline *timeline,
                        guint            current_frame_num,
@@ -153,7 +156,7 @@ timeline_new_frame_cb (ClutterTimeline *timeline,
 
   /* Update alpha value and notify */
   priv->alpha = clutter_alpha_get_alpha (alpha);
-  g_object_notify (G_OBJECT (alpha), "alpha");
+  _clutter_notify_by_pspec (G_OBJECT (alpha), obj_props[PROP_ALPHA]);
 }
 
 static void 
@@ -333,10 +336,11 @@ clutter_alpha_class_init (ClutterAlphaClass *klass)
    * Since: 0.2
    */
   pspec = g_param_spec_object ("timeline",
-                               "Timeline",
-                               "Timeline used by the alpha",
+                               P_("Timeline"),
+                               P_("Timeline used by the alpha"),
                                CLUTTER_TYPE_TIMELINE,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_TIMELINE] = pspec;
   g_object_class_install_property (object_class, PROP_TIMELINE, pspec);
 
   /**
@@ -349,11 +353,12 @@ clutter_alpha_class_init (ClutterAlphaClass *klass)
    * Since: 0.2
    */
   pspec = g_param_spec_double ("alpha",
-                               "Alpha value",
-                               "Alpha value",
+                               P_("Alpha value"),
+                               P_("Alpha value as computed by the alpha"),
                                -1.0, 2.0,
                                0.0,
                                CLUTTER_PARAM_READABLE);
+  obj_props[PROP_ALPHA] = pspec;
   g_object_class_install_property (object_class, PROP_ALPHA, pspec);
 
   /**
@@ -370,11 +375,12 @@ clutter_alpha_class_init (ClutterAlphaClass *klass)
    * Since: 1.0
    */
   pspec = g_param_spec_ulong ("mode",
-                              "Mode",
-                              "Progress mode",
+                              P_("Mode"),
+                              P_("Progress mode"),
                               0, G_MAXULONG,
                               CLUTTER_CUSTOM_MODE,
                               G_PARAM_CONSTRUCT | CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_MODE] = pspec;
   g_object_class_install_property (object_class, PROP_MODE, pspec);
 }
 
@@ -489,7 +495,7 @@ clutter_alpha_set_closure (ClutterAlpha *alpha,
   clutter_alpha_set_closure_internal (alpha, closure);
 
   priv->mode = CLUTTER_CUSTOM_MODE;
-  g_object_notify (G_OBJECT (alpha), "mode");
+  _clutter_notify_by_pspec (G_OBJECT (alpha), obj_props[PROP_MODE]);
 }
 
 /**
@@ -525,7 +531,7 @@ clutter_alpha_set_func (ClutterAlpha    *alpha,
   clutter_alpha_set_closure_internal (alpha, closure);
 
   priv->mode = CLUTTER_CUSTOM_MODE;
-  g_object_notify (G_OBJECT (alpha), "mode");
+  _clutter_notify_by_pspec (G_OBJECT (alpha), obj_props[PROP_MODE]);
 }
 
 /**
@@ -570,7 +576,7 @@ clutter_alpha_set_timeline (ClutterAlpha    *alpha,
                         alpha);
     }
 
-  g_object_notify (G_OBJECT (alpha), "timeline");
+  _clutter_notify_by_pspec (G_OBJECT (alpha), obj_props[PROP_TIMELINE]);
 }
 
 /**
@@ -1292,7 +1298,7 @@ clutter_alpha_set_mode (ClutterAlpha *alpha,
   else
     g_assert_not_reached ();
 
-  g_object_notify (G_OBJECT (alpha), "mode");
+  _clutter_notify_by_pspec (G_OBJECT (alpha), obj_props[PROP_MODE]);
 }
 
 static gulong
