@@ -185,9 +185,13 @@ enum
   PROP_0,
 
   PROP_DURATION,
-  PROP_TIMELINE
+  PROP_TIMELINE,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 static void clutter_scriptable_init (ClutterScriptableIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (ClutterAnimator,
@@ -440,17 +444,11 @@ clutter_animator_finalize (GObject *object)
   g_list_free (priv->score);
   priv->score = NULL;
 
-#if 0
-  for (; priv->score;
-       priv->score = g_list_remove (priv->score, priv->score->data))
-    {
-      clutter_animator_key_free (priv->score->data);
-    }
-#endif
-
   g_object_unref (priv->timeline);
   g_object_unref (priv->slave_timeline);
 
+  g_hash_table_destroy (priv->properties);
+
   G_OBJECT_CLASS (clutter_animator_parent_class)->finalize (object);
 }
 
@@ -1380,7 +1378,7 @@ clutter_animator_get_keys (ClutterAnimator *animator,
       ClutterAnimatorKey *key = k->data;
 
       if ((object == NULL || (object == key->object)) &&
-          (property_name == NULL || ((property_name == key->property_name))) &&
+          (property_name == NULL || (property_name == key->property_name)) &&
           (progress < 0  || fabs (progress - key->progress) < PROGRESS_EPSILON))
         {
           keys = g_list_prepend (keys, key);
@@ -1539,7 +1537,7 @@ parse_animator_property (JsonArray *array,
   GObjectClass *klass;
   GParamSpec *pspec;
   GSList *valid_keys = NULL;
-  GList *k;
+  GList *array_keys, *k;
   ClutterInterpolation interpolation = CLUTTER_INTERPOLATION_LINEAR;
   gboolean ease_in = FALSE;
 
@@ -1611,9 +1609,8 @@ parse_animator_property (JsonArray *array,
   else
     g_value_init (clos->value, G_TYPE_POINTER);
 
-  for (k = json_array_get_elements (keys);
-       k != NULL;
-       k = k->next)
+  array_keys = json_array_get_elements (keys);
+  for (k = array_keys; k != NULL; k = k->next)
     {
       JsonNode *node = k->data;
       JsonArray *key = json_node_get_array (node);
@@ -1652,6 +1649,8 @@ parse_animator_property (JsonArray *array,
       valid_keys = g_slist_prepend (valid_keys, animator_key);
     }
 
+  g_list_free (array_keys);
+
   g_value_set_pointer (clos->value, g_slist_reverse (valid_keys));
 
   clos->result = TRUE;
@@ -1788,6 +1787,7 @@ clutter_animator_class_init (ClutterAnimatorClass *klass)
                              0, G_MAXUINT,
                              2000,
                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_DURATION] = pspec;
   g_object_class_install_property (gobject_class, PROP_DURATION, pspec);
 
   /**
@@ -1803,6 +1803,7 @@ clutter_animator_class_init (ClutterAnimatorClass *klass)
                                P_("The timeline of the animation"),
                                CLUTTER_TYPE_TIMELINE,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_TIMELINE] = pspec;
   g_object_class_install_property (gobject_class, PROP_TIMELINE, pspec);
 }
 
@@ -1821,7 +1822,6 @@ clutter_animator_init (ClutterAnimator *animator)
   clutter_animator_set_timeline (animator, clutter_timeline_new (2000));
 
   priv->slave_timeline = clutter_timeline_new (10000);
-  g_object_ref_sink (priv->slave_timeline);
 }
 
 
@@ -2115,23 +2115,38 @@ gboolean
 clutter_animator_key_get_value (const ClutterAnimatorKey *key,
                                 GValue                   *value)
 {
-  GType gtype;
-
   g_return_val_if_fail (key != NULL, FALSE);
+  g_return_val_if_fail (value != NULL, FALSE);
+  g_return_val_if_fail (G_VALUE_TYPE (value) != G_TYPE_INVALID, FALSE);
 
-  gtype = G_VALUE_TYPE (&key->value);
-
-  if (g_value_type_compatible (gtype, G_VALUE_TYPE (value)))
+  if (!g_type_is_a (G_VALUE_TYPE (&key->value), G_VALUE_TYPE (value)))
     {
-      g_value_copy (&key->value, value);
-      return TRUE;
-    }
+      if (g_value_type_compatible (G_VALUE_TYPE (&key->value),
+                                   G_VALUE_TYPE (value)))
+        {
+          g_value_copy (&key->value, value);
+          return TRUE;
+        }
 
-  if (g_value_type_transformable (gtype, G_VALUE_TYPE (value)))
-    {
-      if (g_value_transform (&key->value, value))
-        return TRUE;
-    }
+      if (g_value_type_transformable (G_VALUE_TYPE (&key->value),
+                                      G_VALUE_TYPE (value)))
+        {
+          if (g_value_transform (&key->value, value))
+            return TRUE;
+        }
 
-  return FALSE;
+      g_warning ("%s: Unable to convert from %s to %s for the "
+                 "property '%s' of object %s in the animator key",
+                 G_STRLOC,
+                 g_type_name (G_VALUE_TYPE (&key->value)),
+                 g_type_name (G_VALUE_TYPE (value)),
+                 key->property_name,
+                 G_OBJECT_TYPE_NAME (key->object));
+
+      return FALSE;
+    }
+  else
+    g_value_copy (&key->value, value);
+
+  return TRUE;
 }
