@@ -38,6 +38,10 @@
  * Since: 0.4
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "clutter-fixed.h"
 #include "clutter-marshal.h"
 #include "clutter-behaviour-ellipse.h"
@@ -70,8 +74,12 @@ enum
   PROP_ANGLE_TILT_Y,
   PROP_ANGLE_TILT_Z,
   PROP_DIRECTION,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 struct _ClutterBehaviourEllipsePrivate
 {
   ClutterKnot  center;
@@ -382,11 +390,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_double ("angle-start",
-                               "Start Angle",
-                               "Initial angle",
+                               P_("Start Angle"),
+                               P_("Initial angle"),
                                0.0, 360.0,
                                0.0,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_ANGLE_START] = pspec;
   g_object_class_install_property (object_class, PROP_ANGLE_START, pspec);
 
   /**
@@ -397,11 +406,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_double ("angle-end",
-                               "End Angle",
-                               "Final angle",
+                               P_("End Angle"),
+                               P_("Final angle"),
                                0.0, 360.0,
                                0.0,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_ANGLE_END] = pspec;
   g_object_class_install_property (object_class, PROP_ANGLE_END, pspec);
 
   /**
@@ -412,11 +422,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_double ("angle-tilt-x",
-                               "Angle x tilt",
-                               "Tilt of the ellipse around x axis",
+                               P_("Angle x tilt"),
+                               P_("Tilt of the ellipse around x axis"),
                                0.0, 360.0,
                                360.0,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_ANGLE_TILT_X] = pspec;
   g_object_class_install_property (object_class, PROP_ANGLE_TILT_X, pspec);
 
   /**
@@ -427,11 +438,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_double ("angle-tilt-y",
-                               "Angle y tilt",
-                               "Tilt of the ellipse around y axis",
+                               P_("Angle y tilt"),
+                               P_("Tilt of the ellipse around y axis"),
                                0.0, 360.0,
                                360.0,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_ANGLE_TILT_Y] = pspec;
   g_object_class_install_property (object_class, PROP_ANGLE_TILT_Y, pspec);
 
   /**
@@ -442,11 +454,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_double ("angle-tilt-z",
-                               "Angle z tilt",
-                               "Tilt of the ellipse around z axis",
+                               P_("Angle z tilt"),
+                               P_("Tilt of the ellipse around z axis"),
                                0.0, 360.0,
                                360.0,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_ANGLE_TILT_Z] = pspec;
   g_object_class_install_property (object_class, PROP_ANGLE_TILT_Z, pspec);
 
   /**
@@ -457,11 +470,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_int ("width",
-                            "Width",
-                            "Width of the ellipse",
+                            P_("Width"),
+                            P_("Width of the ellipse"),
                             0, G_MAXINT,
                             100,
                             CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_WIDTH] = pspec;
   g_object_class_install_property (object_class, PROP_WIDTH, pspec);
 
   /**
@@ -472,11 +486,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_int ("height",
-                            "Height",
-                            "Height of ellipse",
+                            P_("Height"),
+                            P_("Height of ellipse"),
                             0, G_MAXINT,
                             50,
                             CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_HEIGHT] = pspec;
   g_object_class_install_property (object_class, PROP_HEIGHT, pspec);
 
   /**
@@ -487,10 +502,11 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_boxed ("center",
-                              "Center",
-                              "Center of ellipse",
+                              P_("Center"),
+                              P_("Center of ellipse"),
                               CLUTTER_TYPE_KNOT,
                               CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_CENTER] = pspec;
   g_object_class_install_property (object_class, PROP_CENTER, pspec);
 
   /**
@@ -501,11 +517,12 @@ clutter_behaviour_ellipse_class_init (ClutterBehaviourEllipseClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_enum ("direction",
-                             "Direction",
-                             "Direction of rotation",
+                             P_("Direction"),
+                             P_("Direction of rotation"),
                              CLUTTER_TYPE_ROTATE_DIRECTION,
                              CLUTTER_ROTATE_CW,
                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_DIRECTION] = pspec;
   g_object_class_install_property (object_class, PROP_DIRECTION, pspec);
 }
 
@@ -605,7 +622,7 @@ clutter_behaviour_ellipse_set_center (ClutterBehaviourEllipse *self,
       priv->center.x = x;
       priv->center.y = y;
 
-      g_object_notify (G_OBJECT (self), "center");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_CENTER]);
     }
 }
 
@@ -661,7 +678,7 @@ clutter_behaviour_ellipse_set_width (ClutterBehaviourEllipse *self,
     {
       priv->a = width / 2;
 
-      g_object_notify (G_OBJECT (self), "width");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_WIDTH]);
     }
 }
 
@@ -706,7 +723,7 @@ clutter_behaviour_ellipse_set_height (ClutterBehaviourEllipse *self,
     {
       priv->b = height / 2;
 
-      g_object_notify (G_OBJECT (self), "height");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_HEIGHT]);
     }
 }
 
@@ -754,7 +771,7 @@ clutter_behaviour_ellipse_set_angle_start (ClutterBehaviourEllipse *self,
   if (priv->angle_start != new_angle)
     {
       priv->angle_start = new_angle;
-      g_object_notify (G_OBJECT (self), "angle-start");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_START]);
     }
 }
 
@@ -803,7 +820,7 @@ clutter_behaviour_ellipse_set_angle_end (ClutterBehaviourEllipse *self,
     {
       priv->angle_end = new_angle;
 
-      g_object_notify (G_OBJECT (self), "angle-end");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_END]);
     }
 }
 
@@ -854,7 +871,7 @@ clutter_behaviour_ellipse_set_angle_tilt (ClutterBehaviourEllipse *self,
         {
           priv->angle_tilt_x = angle_tilt;
 
-          g_object_notify (G_OBJECT (self), "angle-tilt-x");
+          _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_TILT_X]);
         }
       break;
 
@@ -863,7 +880,7 @@ clutter_behaviour_ellipse_set_angle_tilt (ClutterBehaviourEllipse *self,
         {
           priv->angle_tilt_y = angle_tilt;
 
-          g_object_notify (G_OBJECT (self), "angle-tilt-y");
+          _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_TILT_Y]);
         }
       break;
 
@@ -872,7 +889,7 @@ clutter_behaviour_ellipse_set_angle_tilt (ClutterBehaviourEllipse *self,
         {
           priv->angle_tilt_z = angle_tilt;
 
-          g_object_notify (G_OBJECT (self), "angle-tilt-z");
+          _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_TILT_Z]);
         }
       break;
     }
@@ -939,21 +956,21 @@ clutter_behaviour_ellipse_set_tilt (ClutterBehaviourEllipse *self,
     {
       priv->angle_tilt_x = angle_tilt_x;
 
-      g_object_notify (G_OBJECT (self), "angle-tilt-x");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_TILT_X]);
     }
 
   if (priv->angle_tilt_y != angle_tilt_y)
     {
       priv->angle_tilt_y = angle_tilt_y;
 
-      g_object_notify (G_OBJECT (self), "angle-tilt-y");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_TILT_Y]);
     }
 
   if (priv->angle_tilt_z != angle_tilt_z)
     {
       priv->angle_tilt_z = angle_tilt_z;
 
-      g_object_notify (G_OBJECT (self), "angle-tilt-z");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ANGLE_TILT_Z]);
     }
 
   g_object_thaw_notify (G_OBJECT (self));
@@ -1034,6 +1051,6 @@ clutter_behaviour_ellipse_set_direction (ClutterBehaviourEllipse *self,
     {
       priv->direction = direction;
 
-      g_object_notify (G_OBJECT (self), "direction");
+      _clutter_notify_by_pspec (G_OBJECT (self), obj_props[PROP_DIRECTION]);
     }
 }
