@@ -58,9 +58,13 @@ enum
 {
   PROP_0,
 
-  PROP_BACKEND
+  PROP_BACKEND,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 enum
 {
   DEVICE_ADDED,
@@ -125,11 +129,12 @@ clutter_device_manager_class_init (ClutterDeviceManagerClass *klass)
   gobject_class->get_property = clutter_device_manager_get_property;
 
   pspec = g_param_spec_object ("backend",
-                               "Backend",
-                               "The ClutterBackend of the device manager",
+                               P_("Backend"),
+                               P_("The ClutterBackend of the device manager"),
                                CLUTTER_TYPE_BACKEND,
                                CLUTTER_PARAM_READWRITE |
                                G_PARAM_CONSTRUCT_ONLY);
+  obj_props[PROP_BACKEND] = pspec;
   g_object_class_install_property (gobject_class, PROP_BACKEND, pspec);
 
   /**
