@@ -100,9 +100,13 @@ enum
 
   PROP_DRAG_THRESHOLD,
   PROP_DRAG_HANDLE,
-  PROP_DRAG_AXIS
+  PROP_DRAG_AXIS,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 enum
 {
   DRAG_BEGIN,
@@ -263,6 +267,12 @@ on_captured_event (ClutterActor      *stage,
         emit_drag_end (action, actor, event);
       break;
 
+    case CLUTTER_ENTER:
+    case CLUTTER_LEAVE:
+      if (priv->in_drag)
+        return TRUE;
+      break;
+
     default:
       break;
     }
@@ -467,12 +477,12 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
    * Since: 1.4
    */
   pspec = g_param_spec_uint ("drag-threshold",
-                             "Drag Threshold",
-                             "The amount of pixels required to start "
-                             "dragging",
+                             P_("Drag Threshold"),
+                             P_("The amount of pixels required to start dragging"),
                              0, G_MAXUINT,
                              0,
                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_DRAG_THRESHOLD] = pspec;
   g_object_class_install_property (gobject_class, PROP_DRAG_THRESHOLD, pspec);
 
   /**
@@ -490,10 +500,11 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
    * Since: 1.4
    */
   pspec = g_param_spec_object ("drag-handle",
-                               "Drag Handle",
-                               "The actor that is being dragged",
+                               P_("Drag Handle"),
+                               P_("The actor that is being dragged"),
                                CLUTTER_TYPE_ACTOR,
                                CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_DRAG_HANDLE] = pspec;
   g_object_class_install_property (gobject_class, PROP_DRAG_HANDLE, pspec);
 
   /**
@@ -504,11 +515,12 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
    * Since: 1.4
    */
   pspec = g_param_spec_enum ("drag-axis",
-                             "Drag Axis",
-                             "Constraints the dragging to an axis",
+                             P_("Drag Axis"),
+                             P_("Constraints the dragging to an axis"),
                              CLUTTER_TYPE_DRAG_AXIS,
                              CLUTTER_DRAG_AXIS_NONE,
                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_DRAG_AXIS] = pspec;
   g_object_class_install_property (gobject_class, PROP_DRAG_AXIS, pspec);
 
   /**
@@ -658,7 +670,7 @@ clutter_drag_action_set_drag_threshold (ClutterDragAction *action,
 
   priv->drag_threshold = threshold;
 
-  g_object_notify (G_OBJECT (action), "drag-threshold");
+  _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_THRESHOLD]);
 }
 
 /**
@@ -704,7 +716,7 @@ clutter_drag_action_set_drag_handle (ClutterDragAction *action,
 
   priv->drag_handle = handle;
 
-  g_object_notify (G_OBJECT (action), "drag-handle");
+  _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_HANDLE]);
 }
 
 /**
@@ -752,7 +764,7 @@ clutter_drag_action_set_drag_axis (ClutterDragAction *action,
 
   priv->drag_axis = axis;
 
-  g_object_notify (G_OBJECT (action), "drag-axis");
+  _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_AXIS]);
 }
 
 /**
