@@ -60,6 +60,7 @@
 #include "clutter-color.h"
 #include "clutter-fixed.h"
 #include "clutter-interval.h"
+#include "clutter-private.h"
 #include "clutter-units.h"
 
 typedef struct
@@ -74,7 +75,20 @@ enum
 {
   PROP_0,
 
-  PROP_VALUE_TYPE
+  PROP_VALUE_TYPE,
+
+  PROP_LAST
+};
+
+static GParamSpec *obj_props[PROP_LAST];
+
+enum
+{
+  INITIAL = 0,
+  FINAL,
+  RESULT,
+
+  N_VALUES
 };
 
 #define CLUTTER_INTERVAL_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_INTERVAL, ClutterIntervalPrivate))
@@ -307,6 +321,17 @@ clutter_interval_real_compute_value (ClutterInterval *interval,
       break;
     }
 
+  /* We're trying to animate a property without knowing how to do that. Issue
+   * a warning with a hint to what could be done to fix that */
+  if (G_UNLIKELY (retval == FALSE))
+    {
+      g_warning ("%s: Could not compute progress between two %ss. You can "
+                 "register a progress function to instruct ClutterInterval "
+                 "how to deal with this GType",
+                 G_STRLOC,
+                 g_type_name (value_type));
+    }
+
   return retval;
 }
 
@@ -384,10 +409,11 @@ clutter_interval_class_init (ClutterIntervalClass *klass)
    * Since: 1.0
    */
   pspec = g_param_spec_gtype ("value-type",
-                              "Value Type",
-                              "The type of the values in the interval",
+                              P_("Value Type"),
+                              P_("The type of the values in the interval"),
                               G_TYPE_NONE,
                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+  obj_props[PROP_VALUE_TYPE] = pspec;
   g_object_class_install_property (gobject_class, PROP_VALUE_TYPE, pspec);
 }
 
@@ -399,7 +425,7 @@ clutter_interval_init (ClutterInterval *self)
   self->priv = priv = CLUTTER_INTERVAL_GET_PRIVATE (self);
 
   priv->value_type = G_TYPE_INVALID;
-  priv->values = g_malloc0 (sizeof (GValue) * 2);
+  priv->values = g_malloc0 (sizeof (GValue) * N_VALUES);
 }
 
 static void
@@ -411,8 +437,13 @@ clutter_interval_set_interval_valist (ClutterInterval *interval,
   gchar *error;
 
   /* initial value */
+#if GLIB_CHECK_VERSION (2, 23, 2)
+  G_VALUE_COLLECT_INIT (&value, gtype, var_args, 0, &error);
+#else
   g_value_init (&value, gtype);
   G_VALUE_COLLECT (&value, var_args, 0, &error);
+#endif /* GLIB_CHECK_VERSION (2, 23, 2) */
+
   if (error)
     {
       g_warning ("%s: %s", G_STRLOC, error);
@@ -429,8 +460,13 @@ clutter_interval_set_interval_valist (ClutterInterval *interval,
   g_value_unset (&value);
 
   /* final value */
+#if GLIB_CHECK_VERSION (2, 23, 2)
+  G_VALUE_COLLECT_INIT (&value, gtype, var_args, 0, &error);
+#else
   g_value_init (&value, gtype);
   G_VALUE_COLLECT (&value, var_args, 0, &error);
+#endif /* GLIB_CHECK_VERSION (2, 23, 2) */
+
   if (error)
     {
       g_warning ("%s: %s", G_STRLOC, error);
@@ -612,6 +648,8 @@ clutter_interval_set_value_internal (ClutterInterval *interval,
 {
   ClutterIntervalPrivate *priv = interval->priv;
 
+  g_assert (index_ >= INITIAL && index_ <= RESULT);
+
   if (G_IS_VALUE (&priv->values[index_]))
     g_value_unset (&priv->values[index_]);
 
@@ -626,6 +664,8 @@ clutter_interval_get_value_internal (ClutterInterval *interval,
 {
   ClutterIntervalPrivate *priv = interval->priv;
 
+  g_assert (index_ >= INITIAL && index_ <= RESULT);
+
   g_value_copy (&priv->values[index_], value);
 }
 
@@ -652,7 +692,7 @@ clutter_interval_set_initial_value (ClutterInterval *interval,
 
   g_return_if_fail (G_VALUE_TYPE (value) == priv->value_type);
 
-  clutter_interval_set_value_internal (interval, 0, value);
+  clutter_interval_set_value_internal (interval, INITIAL, value);
 }
 
 /**
@@ -672,14 +712,10 @@ void
 clutter_interval_get_initial_value (ClutterInterval *interval,
                                     GValue          *value)
 {
-  ClutterIntervalPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_INTERVAL (interval));
   g_return_if_fail (value != NULL);
 
-  priv = interval->priv;
-
-  clutter_interval_get_value_internal (interval, 0, value);
+  clutter_interval_get_value_internal (interval, INITIAL, value);
 }
 
 /**
@@ -699,7 +735,7 @@ clutter_interval_peek_initial_value (ClutterInterval *interval)
 {
   g_return_val_if_fail (CLUTTER_IS_INTERVAL (interval), NULL);
 
-  return interval->priv->values;
+  return interval->priv->values + INITIAL;
 }
 
 /**
@@ -725,7 +761,7 @@ clutter_interval_set_final_value (ClutterInterval *interval,
 
   g_return_if_fail (G_VALUE_TYPE (value) == priv->value_type);
 
-  clutter_interval_set_value_internal (interval, 1, value);
+  clutter_interval_set_value_internal (interval, FINAL, value);
 }
 
 /**
@@ -745,14 +781,10 @@ void
 clutter_interval_get_final_value (ClutterInterval *interval,
                                   GValue          *value)
 {
-  ClutterIntervalPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_INTERVAL (interval));
   g_return_if_fail (value != NULL);
 
-  priv = interval->priv;
-
-  clutter_interval_get_value_internal (interval, 1, value);
+  clutter_interval_get_value_internal (interval, FINAL, value);
 }
 
 /**
@@ -772,7 +804,7 @@ clutter_interval_peek_final_value (ClutterInterval *interval)
 {
   g_return_val_if_fail (CLUTTER_IS_INTERVAL (interval), NULL);
 
-  return interval->priv->values + 1;
+  return interval->priv->values + FINAL;
 }
 
 /**
@@ -872,7 +904,7 @@ clutter_interval_validate (ClutterInterval *interval,
  * @value: return location for an initialized #GValue
  *
  * Computes the value between the @interval boundaries given the
- * progress @factor and puts it into @value.
+ * progress @factor and copies it into @value.
  *
  * Return value: %TRUE if the operation was successful
  *
@@ -891,6 +923,50 @@ clutter_interval_compute_value (ClutterInterval *interval,
                                                                value);
 }
 
+/**
+ * clutter_interval_compute:
+ * @interval: a #ClutterInterval
+ * @factor: the progress factor, between 0 and 1
+ *
+ * Computes the value between the @interval boundaries given the
+ * progress @factor
+ *
+ * Unlike clutter_interval_compute_value(), this function will
+ * return a const pointer to the computed value
+ *
+ * You should use this function if you immediately pass the computed
+ * value to another function that makes a copy of it, like
+ * g_object_set_property()
+ *
+ * Return value: (transfer none): a pointer to the computed value,
+ *   or %NULL if the computation was not successfull
+ *
+ * Since: 1.4
+ */
+G_CONST_RETURN GValue *
+clutter_interval_compute (ClutterInterval *interval,
+                          gdouble          factor)
+{
+  GValue *value;
+  gboolean res;
+
+  g_return_val_if_fail (CLUTTER_IS_INTERVAL (interval), NULL);
+
+  value = &(interval->priv->values[RESULT]);
+
+  if (G_VALUE_TYPE (value) == G_TYPE_INVALID)
+    g_value_init (value, interval->priv->value_type);
+
+  res = CLUTTER_INTERVAL_GET_CLASS (interval)->compute_value (interval,
+                                                              factor,
+                                                              value);
+
+  if (res)
+    return interval->priv->values + RESULT;
+
+  return NULL;
+}
+
 /**
  * clutter_interval_register_progress_func:
  * @value_type: a #GType
