@@ -81,6 +81,8 @@ struct _ClutterTexturePrivate
 
   CoglHandle pick_material;
 
+  gchar *filename;
+
   ClutterTextureAsyncData *async_data;
 
   guint no_slice : 1;
@@ -142,9 +144,13 @@ enum
   PROP_KEEP_ASPECT_RATIO,
   PROP_LOAD_ASYNC,
   PROP_LOAD_DATA_ASYNC,
-  PROP_PICK_WITH_ALPHA
+  PROP_PICK_WITH_ALPHA,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 enum
 {
   SIZE_CHANGE,
@@ -753,6 +759,8 @@ clutter_texture_finalize (GObject *object)
       priv->pick_material = COGL_INVALID_HANDLE;
     }
 
+  g_free (priv->filename);
+
   G_OBJECT_CLASS (clutter_texture_parent_class)->finalize (object);
 }
 
@@ -900,6 +908,10 @@ clutter_texture_get_property (GObject    *object,
       g_value_set_boolean (value, priv->pick_with_alpha);
       break;
 
+    case PROP_FILENAME:
+      g_value_set_string (value, priv->filename);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -934,6 +946,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Auto sync size of actor to underlying pixbuf dimensions"),
                                 TRUE,
                                 CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_SYNC_SIZE] = pspec;
   g_object_class_install_property (gobject_class, PROP_SYNC_SIZE, pspec);
 
   pspec = g_param_spec_boolean ("disable-slicing",
@@ -942,6 +955,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 FALSE,
                                 G_PARAM_CONSTRUCT_ONLY |
                                 CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_NO_SLICE] = pspec;
   g_object_class_install_property (gobject_class, PROP_NO_SLICE, pspec);
 
   pspec = g_param_spec_int ("tile-waste",
@@ -950,6 +964,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                             -1, G_MAXINT,
                             COGL_TEXTURE_MAX_WASTE,
                             CLUTTER_PARAM_READABLE);
+  obj_props[PROP_MAX_TILE_WASTE] = pspec;
   g_object_class_install_property (gobject_class, PROP_MAX_TILE_WASTE, pspec);
 
   pspec = g_param_spec_boolean ("repeat-x",
@@ -957,6 +972,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Repeat the contents rather than scaling them horizontally."),
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_REPEAT_X] = pspec;
   g_object_class_install_property (gobject_class, PROP_REPEAT_X, pspec);
 
   pspec = g_param_spec_boolean ("repeat-y",
@@ -964,6 +980,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Repeat the contents rather than scaling them vertically."),
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_REPEAT_Y] = pspec;
   g_object_class_install_property (gobject_class, PROP_REPEAT_Y, pspec);
 
   pspec = g_param_spec_enum ("filter-quality",
@@ -972,6 +989,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                              CLUTTER_TYPE_TEXTURE_QUALITY,
                              CLUTTER_TEXTURE_QUALITY_MEDIUM,
                              G_PARAM_CONSTRUCT | CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_FILTER_QUALITY] = pspec;
   g_object_class_install_property (gobject_class, PROP_FILTER_QUALITY, pspec);
 
   pspec = g_param_spec_enum ("pixel-format",
@@ -980,27 +998,40 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                              COGL_TYPE_PIXEL_FORMAT,
                              COGL_PIXEL_FORMAT_RGBA_8888,
                              CLUTTER_PARAM_READABLE);
+  obj_props[PROP_PIXEL_FORMAT] = pspec;
   g_object_class_install_property (gobject_class, PROP_PIXEL_FORMAT, pspec);
 
   pspec = g_param_spec_boxed ("cogl-texture",
                               P_("COGL Texture"),
                               P_("The underlying COGL texture handle used to draw this actor"),
                               COGL_TYPE_HANDLE,
-                              G_PARAM_READWRITE);
+                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_COGL_TEXTURE] = pspec;
   g_object_class_install_property (gobject_class, PROP_COGL_TEXTURE, pspec);
 
   pspec = g_param_spec_boxed ("cogl-material",
                               P_("COGL Material"),
                               P_("The underlying COGL material handle used to draw this actor"),
                               COGL_TYPE_HANDLE,
-                              G_PARAM_READWRITE);
+                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_COGL_MATERIAL] = pspec;
   g_object_class_install_property (gobject_class, PROP_COGL_MATERIAL, pspec);
 
+  /**
+   * ClutterTexture:filename:
+   *
+   * The path of the file containing the image data to be displayed by
+   * the texture.
+   *
+   * This property is unset when using the clutter_texture_set_from_*_data()
+   * family of functions.
+   */
   pspec = g_param_spec_string ("filename",
                                P_("Filename"),
-                               P_("The full path of the file containing the texture"),
+                               P_("The path of the file containing the image data"),
                                NULL,
-                               G_PARAM_WRITABLE);
+                               CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_FILENAME] = pspec;
   g_object_class_install_property (gobject_class, PROP_FILENAME, pspec);
 
   pspec = g_param_spec_boolean ("keep-aspect-ratio",
@@ -1008,6 +1039,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Keep the aspect ratio of the texture when requesting the preferred width or height"),
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_KEEP_ASPECT_RATIO] = pspec;
   g_object_class_install_property (gobject_class, PROP_KEEP_ASPECT_RATIO, pspec);
 
   /**
@@ -1034,6 +1066,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Load files inside a thread to avoid blocking when loading images from disk."),
                                 FALSE,
                                 CLUTTER_PARAM_WRITABLE);
+  obj_props[PROP_LOAD_ASYNC] = pspec;
   g_object_class_install_property (gobject_class, PROP_LOAD_ASYNC, pspec);
 
 
@@ -1050,6 +1083,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Decode image data files inside a thread to reduce blocking when loading images from disk."),
                                 FALSE,
                                 CLUTTER_PARAM_WRITABLE);
+  obj_props[PROP_LOAD_DATA_ASYNC] = pspec;
   g_object_class_install_property (gobject_class, PROP_LOAD_DATA_ASYNC, pspec);
 
   /**
@@ -1074,6 +1108,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
                                 P_("Shape actor with alpha channel when picking"),
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_PICK_WITH_ALPHA] = pspec;
   g_object_class_install_property (gobject_class, PROP_PICK_WITH_ALPHA, pspec);
 
   /**
@@ -1367,16 +1402,39 @@ clutter_texture_set_cogl_texture (ClutterTexture  *texture,
                      priv->image_height);
 
       if (priv->sync_actor_size)
-        clutter_actor_queue_relayout (CLUTTER_ACTOR (texture));
+        {
+          ClutterActor *actor = CLUTTER_ACTOR (texture);
+
+          /* we have been requested to keep the actor size in
+           * sync with the texture data; if we also want to
+           * maintain the aspect ratio we want to change the
+           * requisition mode depending on the orientation of
+           * the texture, so that the parent container can do
+           * the right thing
+           */
+          if (priv->keep_aspect_ratio)
+            {
+              ClutterRequestMode request;
+
+              if (priv->image_width > priv->image_height)
+                request = CLUTTER_REQUEST_HEIGHT_FOR_WIDTH;
+              else
+                request = CLUTTER_REQUEST_WIDTH_FOR_HEIGHT;
+
+              clutter_actor_set_request_mode (actor, request);
+            }
+
+          clutter_actor_queue_relayout (CLUTTER_ACTOR (texture));
+        }
     }
 
   /* rename signal */
   g_signal_emit (texture, texture_signals[PIXBUF_CHANGE], 0);
 
-  g_object_notify (G_OBJECT (texture), "cogl-texture");
-
   /* If resized actor may need resizing but paint() will do this */
   clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
+
+  _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_COGL_TEXTURE]);
 }
 
 static gboolean
@@ -1424,6 +1482,9 @@ clutter_texture_set_from_data (ClutterTexture     *texture,
       return FALSE;
     }
 
+  g_free (priv->filename);
+  priv->filename = NULL;
+
   clutter_texture_set_cogl_texture (texture, new_texture);
 
   cogl_handle_unref (new_texture);
@@ -1913,12 +1974,17 @@ clutter_texture_set_from_file (ClutterTexture *texture,
       return FALSE;
     }
 
+  g_free (priv->filename);
+  priv->filename = g_strdup (filename);
+
   clutter_texture_set_cogl_texture (texture, new_texture);
 
   cogl_handle_unref (new_texture);
 
   g_signal_emit (texture, texture_signals[LOAD_FINISHED], 0, NULL);
 
+  _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_FILENAME]);
+
   return TRUE;
 }
 
@@ -1963,9 +2029,9 @@ clutter_texture_set_filter_quality (ClutterTexture        *texture,
       cogl_material_set_layer_filters (priv->material, 0,
                                        min_filter, mag_filter);
 
-      g_object_notify (G_OBJECT (texture), "filter-quality");
-
       clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
+
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_FILTER_QUALITY]);
     }
 }
 
@@ -2206,6 +2272,9 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
       return FALSE;
     }
 
+  g_free (texture->priv->filename);
+  texture->priv->filename = NULL;
+
   /* rename signal */
   g_signal_emit (texture, texture_signals[PIXBUF_CHANGE], 0);
 
@@ -2507,7 +2576,7 @@ clutter_texture_set_sync_size (ClutterTexture *texture,
 
       clutter_actor_queue_relayout (CLUTTER_ACTOR (texture));
 
-      g_object_notify (G_OBJECT (texture), "sync-size");
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_SYNC_SIZE]);
     }
 }
 
@@ -2559,7 +2628,7 @@ clutter_texture_set_repeat (ClutterTexture *texture,
     {
       priv->repeat_x = repeat_x;
 
-      g_object_notify (G_OBJECT (texture), "repeat-x");
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_REPEAT_X]);
 
       changed = TRUE;
     }
@@ -2568,7 +2637,7 @@ clutter_texture_set_repeat (ClutterTexture *texture,
     {
       priv->repeat_y = repeat_y;
 
-      g_object_notify (G_OBJECT (texture), "repeat-y");
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_REPEAT_Y]);
 
       changed = TRUE;
     }
@@ -2662,7 +2731,7 @@ clutter_texture_set_keep_aspect_ratio (ClutterTexture *texture,
 
       clutter_actor_queue_relayout (CLUTTER_ACTOR (texture));
 
-      g_object_notify (G_OBJECT (texture), "keep-aspect-ratio");
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_KEEP_ASPECT_RATIO]);
     }
 }
 
@@ -2717,8 +2786,8 @@ clutter_texture_set_load_async (ClutterTexture *texture,
 
       priv->load_async_set = load_async;
 
-      g_object_notify (G_OBJECT (texture), "load-async");
-      g_object_notify (G_OBJECT (texture), "load-data-async");
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_ASYNC]);
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_DATA_ASYNC]);
     }
 }
 
@@ -2775,8 +2844,8 @@ clutter_texture_set_load_data_async (ClutterTexture *texture,
 
       priv->load_async_set = load_async;
 
-      g_object_notify (G_OBJECT (texture), "load-async");
-      g_object_notify (G_OBJECT (texture), "load-data-async");
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_ASYNC]);
+      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_DATA_ASYNC]);
     }
 }
 
