@@ -275,7 +275,7 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
                         height);
 
           CLUTTER_SET_PRIVATE_FLAGS (stage_x11->wrapper,
-                                     CLUTTER_STAGE_IN_RESIZE);
+                                     CLUTTER_IN_RESIZE);
 
           XResizeWindow (backend_x11->xdpy,
                          stage_x11->xwin,
@@ -436,7 +436,7 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
 
   CLUTTER_NOTE (BACKEND, "%ssetting fullscreen", is_fullscreen ? "" : "un");
 
-  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_ACTOR_SYNC_MATRICES);
+  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_SYNC_MATRICES);
 
   if (is_fullscreen)
     {
@@ -711,8 +711,6 @@ clutter_stage_x11_init (ClutterStageX11 *stage)
   stage->title = NULL;
 
   stage->wrapper = NULL;
-
-  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_ACTOR_IS_TOPLEVEL);
 }
 
 static void
@@ -890,14 +888,13 @@ clutter_x11_set_stage_foreign (ClutterStage *stage,
   backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
   g_return_val_if_fail (CLUTTER_IS_STAGE (stage), FALSE);
+  g_return_val_if_fail (!CLUTTER_ACTOR_IN_DESTRUCTION (stage), FALSE);
   g_return_val_if_fail (xwindow != None, FALSE);
 
   actor = CLUTTER_ACTOR (stage);
 
-  impl = _clutter_stage_get_window (stage);
-  stage_x11 = CLUTTER_STAGE_X11 (impl);
-
   xvisinfo = clutter_backend_x11_get_visual_info (backend_x11);
+  g_return_val_if_fail (xvisinfo != NULL, FALSE);
 
   clutter_x11_trap_x_errors ();
 
@@ -908,15 +905,32 @@ clutter_x11_set_stage_foreign (ClutterStage *stage,
                          &border,
                          &depth);
 
-  if (clutter_x11_untrap_x_errors () ||
-      !status ||
-      width == 0 || height == 0 ||
-      depth != xvisinfo->depth)
+  if (clutter_x11_untrap_x_errors () || !status)
     {
-      g_warning ("Unable to retrieve the new window geometry");
+      g_critical ("Unable to retrieve the geometry of the foreign window: "
+                  "XGetGeometry() failed (status code: %d)", status);
       return FALSE;
     }
 
+  if (width == 0 || height == 0)
+    {
+      g_warning ("The size of the foreign window is 0x0");
+      return FALSE;
+    }
+
+  if (depth != xvisinfo->depth)
+    {
+      g_warning ("The depth of the visual of the foreign window is %d, but "
+                 "Clutter has been initialized to require a visual depth "
+                 "of %d",
+                 depth,
+                 xvisinfo->depth);
+      return FALSE;
+    }
+
+  impl = _clutter_stage_get_window (stage);
+  stage_x11 = CLUTTER_STAGE_X11 (impl);
+
   fwd.stage_x11 = stage_x11;
   fwd.xwindow = xwindow;
 
