@@ -16,13 +16,14 @@
 #include <X11/Xlib.h>
 #include <X11/extensions/Xcomposite.h>
 
-#define IMAGE "redhand.png"
+#define IMAGE   TESTS_DATADIR G_DIR_SEPARATOR_S "redhand.png"
 
 # ifdef USE_GDKPIXBUF
 # include <gdk-pixbuf/gdk-pixbuf.h>
 
 static gboolean disable_x11 = FALSE;
 static gboolean disable_glx = FALSE;
+static gboolean disable_animation = FALSE;
 
 static GOptionEntry g_options[] =
 {
@@ -38,10 +39,44 @@ static GOptionEntry g_options[] =
     &disable_glx,
     "Disable redirection through GLX pixmap",
     NULL },
+  { "disable-animation",
+    0, 0,
+    G_OPTION_ARG_NONE,
+    &disable_animation,
+    "Disable the animations",
+    NULL },
 
   { NULL }
 };
 
+static void
+toggle_texture_quality (ClutterActor *actor)
+{
+  if (CLUTTER_IS_CONTAINER (actor))
+    clutter_container_foreach (CLUTTER_CONTAINER (actor),
+                               (ClutterCallback) toggle_texture_quality,
+                               NULL);
+
+  if (CLUTTER_IS_TEXTURE (actor))
+    {
+      ClutterTextureQuality quality;
+
+      quality = clutter_texture_get_filter_quality (CLUTTER_TEXTURE (actor));
+
+      if (quality == CLUTTER_TEXTURE_QUALITY_HIGH)
+        quality = CLUTTER_TEXTURE_QUALITY_MEDIUM;
+      else
+        quality = CLUTTER_TEXTURE_QUALITY_HIGH;
+
+      g_print ("switching to quality %s for %p\n",
+               quality == CLUTTER_TEXTURE_QUALITY_HIGH
+               ? "high" : "medium",
+               actor);
+
+      clutter_texture_set_filter_quality (CLUTTER_TEXTURE (actor), quality);
+    }
+}
+
 static gboolean
 stage_key_release_cb (ClutterActor *actor,
 		      ClutterEvent *event,
@@ -53,6 +88,10 @@ stage_key_release_cb (ClutterActor *actor,
     case CLUTTER_Q:
       clutter_main_quit ();
       break;
+
+    case CLUTTER_m:
+      toggle_texture_quality (actor);
+      break;
     }
   return FALSE;
 }
@@ -64,16 +103,29 @@ stage_button_press_cb (ClutterActor    *actor,
 {
   Pixmap        pxm = (Pixmap)data;
   Display      *dpy = clutter_x11_get_default_display ();
-  GC            gc;
-  XGCValues     gc_values = {0};
+  static GC     gc = None;
+  static int    x = 100, y = 100;
 
+  if (gc == None)
+    {
+      XGCValues gc_values = { 0 };
 
-  gc = XCreateGC (dpy,
-                  pxm,
-                  0,
-                  &gc_values);
+      gc_values.line_width = 12;
+      /* This is an attempt to get a black pixel will full
+         opacity. Seemingly the BlackPixel macro and the default GC
+         value are a fully transparent color */
+      gc_values.foreground = 0xff000000;
 
-  XDrawLine (dpy, pxm, gc, 0, 0, 100, 100);
+      gc = XCreateGC (dpy,
+                      pxm,
+                      GCLineWidth | GCForeground,
+                      &gc_values);
+    }
+
+  XDrawArc (dpy, pxm, gc, x, y, 100, 100, 0, 360 * 64);
+
+  x -= 5;
+  y -= 5;
 
   return FALSE;
 }
@@ -105,7 +157,7 @@ create_pixmap (guint *width, guint *height, guint *depth)
 
   data = g_malloc (w * h * 4);
   image = XCreateImage (dpy,
-                        None,
+                        NULL,
                         32,
                         ZPixmap,
                         0,
@@ -196,7 +248,7 @@ test_pixmap_main (int argc, char **argv)
   Display	      *xdpy;
   int		       screen;
   Window	       rootwin;
-  ClutterActor        *group, *label, *stage, *tex;
+  ClutterActor        *group = NULL, *label, *stage, *tex;
   Pixmap               pixmap;
   const ClutterColor   gry = { 0x99, 0x99, 0x99, 0xFF };
   Window               win_remote;
@@ -241,19 +293,24 @@ test_pixmap_main (int argc, char **argv)
   alpha = clutter_alpha_new_full (timeline, CLUTTER_LINEAR);
   depth_behavior = clutter_behaviour_depth_new (alpha, -2500, 400);
 
-  group = clutter_group_new ();
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), group);
-  label = clutter_text_new_with_text ("fixed", "ClutterX11Texture (Window)");
-  clutter_container_add_actor (CLUTTER_CONTAINER (group), label);
-  tex = clutter_x11_texture_pixmap_new_with_window (win_remote);
-  clutter_container_add_actor (CLUTTER_CONTAINER (group), tex);
-  clutter_actor_set_position (tex, 0, 20);
-  clutter_x11_texture_pixmap_set_automatic (CLUTTER_X11_TEXTURE_PIXMAP (tex),
-					    TRUE);
-  clutter_texture_set_filter_quality (CLUTTER_TEXTURE (tex),
-				      CLUTTER_TEXTURE_QUALITY_HIGH);
-  clutter_actor_set_position (group, 0, 0);
-  clutter_behaviour_apply (depth_behavior, group);
+  if (!disable_x11)
+    {
+      group = clutter_group_new ();
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), group);
+      label = clutter_text_new_with_text ("fixed",
+                                          "ClutterX11Texture (Window)");
+      clutter_container_add_actor (CLUTTER_CONTAINER (group), label);
+      tex = clutter_x11_texture_pixmap_new_with_window (win_remote);
+      clutter_container_add_actor (CLUTTER_CONTAINER (group), tex);
+      clutter_actor_set_position (tex, 0, 20);
+      clutter_x11_texture_pixmap_set_automatic (CLUTTER_X11_TEXTURE_PIXMAP (tex),
+                                                TRUE);
+      clutter_texture_set_filter_quality (CLUTTER_TEXTURE (tex),
+                                          CLUTTER_TEXTURE_QUALITY_HIGH);
+      clutter_actor_set_position (group, 0, 0);
+      if (!disable_animation)
+        clutter_behaviour_apply (depth_behavior, group);
+    }
 
 #ifdef HAVE_CLUTTER_GLX
   /* a window with glx */
@@ -275,7 +332,8 @@ test_pixmap_main (int argc, char **argv)
 				  clutter_actor_get_width (stage)
 				  - clutter_actor_get_width (tex),
 				  0);
-      clutter_behaviour_apply (depth_behavior, group);
+      if (!disable_animation)
+        clutter_behaviour_apply (depth_behavior, group);
 
       if (!clutter_glx_texture_pixmap_using_extension (
 				      CLUTTER_GLX_TEXTURE_PIXMAP (tex)))
@@ -283,7 +341,10 @@ test_pixmap_main (int argc, char **argv)
     }
 #endif /* HAVE_CLUTTER_GLX */
 
-  row_height = clutter_actor_get_height (group);
+  if (group)
+    row_height = clutter_actor_get_height (group);
+  else
+    row_height = 0;
 
   /* NB: We only draw on the window after being redirected, so we dont
    * have to worry about handling expose events... */
@@ -300,6 +361,8 @@ test_pixmap_main (int argc, char **argv)
   label = clutter_text_new_with_text ("fixed", "ClutterX11Texture (Pixmap)");
   clutter_container_add_actor (CLUTTER_CONTAINER (group), label);
   tex = clutter_x11_texture_pixmap_new_with_pixmap (pixmap);
+  clutter_x11_texture_pixmap_set_automatic (CLUTTER_X11_TEXTURE_PIXMAP (tex),
+                                            TRUE);
   clutter_container_add_actor (CLUTTER_CONTAINER (group), tex);
   clutter_actor_set_position (tex, 0, 20);
   clutter_texture_set_filter_quality (CLUTTER_TEXTURE (tex),
@@ -307,7 +370,8 @@ test_pixmap_main (int argc, char **argv)
   /* oddly, the actor's size is 0 until it is realized, even though
      pixmap-height is set */
   clutter_actor_set_position (group, 0, row_height);
-  clutter_behaviour_apply (depth_behavior, group);
+  if (!disable_animation)
+    clutter_behaviour_apply (depth_behavior, group);
 
 
   g_signal_connect (stage, "key-release-event",
@@ -317,7 +381,8 @@ test_pixmap_main (int argc, char **argv)
 
   clutter_actor_show (stage);
 
-  clutter_timeline_start (timeline);
+  if (!disable_animation)
+    clutter_timeline_start (timeline);
 
   clutter_main ();
 # endif /* USE_GDKPIXBUF */
